# Writing Tests for Importable Python Modules

## Package Layout

See [Writing Tests for Command Line Utilities](CommandLine.md)
for more details on each topic covered here.

We lay out an imaginary package as follows:

```text
mypackage/

    README.md
    setup.py
    requirements.txt

    tests/
        __init__.py
        test_mypackage.py
        ...

    mypackage/
        __init__.py
        ...
```

This is an alternative package layout to the one shown in 
[Writing Tests for Command Line Utilities](CommandLine.md).

As before, we include the `__version__` variable
in the `mypackage/__init__.py` file:

**`mypackage/__init__.py`:**

```python
__version__ = "0.0.0"
```

## Test Details in setup.py

As with the [command line](CommandLine.md) guide, 
we use the `test_suite` to set what program to use
to run the test suite and `tests_require` to specify
what packages are required to run tests.

```python
setup(
        ...
        test_suite = ... ,
        tests_require = ... ,
        ...
)
```

As before, we use nose:

```
setup(
        ...

        test_suite='nose.collector',
        tests_require=['nose'],

        ...
)
```

Once we specify how to run the test suite, we should be
able to run tests from `setup.py` like so:

```
python setup.py test
```

## Writing Tests

We cover the contents of `test_mypackage.py` to test 
the package.

The first thing we need in the test file is the import statement
that makes the `main()` method of the command line utility 
availabile to us:

```
from mypackagecli.command import main
```


